@@ -1,19 +1,11 @@
-# RT::Extension::ReferenceIDoitObjects
-#
-# Copyright 2011-12 synetics GmbH, http://i-doit.org/
-#
-# This program is free software; you can redistribute it and/or modify it under
-# the same terms as Perl itself.
-#
-# Request Tracker (RT) is Copyright Best Practical Solutions, LLC.
-
 package RT::Extension::ReferenceIDoitObjects;
 
 use 5.010;
 use warnings;
 use strict;
 
-our $VERSION = '0.10';
+our $VERSION = '0.2';
+
 
 =head1 NAME
 
@@ -32,7 +24,7 @@ i-doit's multi-mandator functionality.
 i-doit ("I document IT") is a web-based tool to document complex IT
 infrastructures. It provides several modules like a ITIL compliant Configuration
 Management Database (CMDB). More information about i-doit is available under
-L<http://www.i-doit.org/>. Its core is Free and Open Source Software. Visit
+L<http://www.i-doit.org/>. It's core is Free and Open Source Software. Visit
 L<http://www.i-doit.com/> for commercial support and additional services. Please
 note, that B<i-doit's API (which is essential for this extension) is currently
 only implemented in the commercial branch>.
@@ -41,7 +33,7 @@ only implemented in the commercial branch>.
 =head1 INSTALLATION
 
 This extension requires RT 4.x or higher and a running installation of i-doit
-0.9.9-9 or higher.
+0.9.9-8 or higher.
 
 To install this extension, run the following commands:
 
@@ -74,7 +66,7 @@ i-doit has a built-in API based on JSON-RPC. To call this API set its URL:
 
     Set($IDoitDefaultMandator, 1);
 
-    Set($IDoitDefaultView, 'object'); # 'object', 'tree' or 'item'
+    Set($IDoitDefaultView, 'tree'); # 'object', 'tree' or 'item'
 
     Set($IDoitShowCustomFields, 1); # 1 ('yes') or 0 ('no')
 
@@ -118,8 +110,7 @@ The user's password is encoded as a MD5 hash.
 
 You need the identifier of a mandator who owns the objects, but this may also be
 set while creating a ticket. This identifier has be to added to the list of the
-corresponding custom field. For a list of (activated) mandators and their
-identifiers see i-doit's admin center.
+corresponding custom field.
 
 
 =item C<$IDoitDefaultView>
@@ -170,14 +161,6 @@ This is an example for deleting the mason cache and restarting the Apache HTTP
 web server on a Debian GNU/Linux based operating system.
 
 
-=head1 USAGE
-
-Whenever you create a new ticket or edit an existing one you are able to
-reference this ticket with one or more objects in i-doit. An additional box
-with the so-called "object browser" will shown up. Just select the objects you
-need or unselect the objects you don't need.
-
-
 =head1 AUTHORS
 
 Benjamin Heisig, E<lt>bheisig@synetics.deE<gt>
@@ -212,10 +195,6 @@ L<http://annocpan.org/dist/RT-Extension-ReferenceIDoitObjects>
 
 L<http://cpanratings.perl.org/d/RT-Extension-ReferenceIDoitObjects>
 
-=item B<Repository>
-
-L<https://github.com/bheisig/rt-extension-referenceidoitobjects>
-
 =back
 
 
@@ -226,7 +205,7 @@ Please report any bugs or feature requests to the L<authors|/"AUTHORS">.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2011-12 synetics GmbH, E<lt>http://i-doit.org/E<gt>
+Copyright 2011 synetics GmbH, E<lt>http://i-doit.org/E<gt>
 
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
@@ -241,4 +220,6 @@ Request Tracker (RT) is Copyright Best Practical Solutions, LLC.
 
 =cut
 
+
 1;
+
